==> s2i-annotations-0.10.5-sources.jar: io/dekorate/s2i/config/S2iBuildConfigFluent.java <==
package io.dekorate.s2i.config;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.kubernetes.config.ConfigKey;
import java.lang.StringBuilder;
import io.dekorate.kubernetes.config.EnvFluent;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import io.dekorate.kubernetes.config.ImageConfigurationFluent;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import io.dekorate.project.Project;
import java.lang.StringBuffer;
import io.dekorate.kubernetes.config.EnvBuilder;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface S2iBuildConfigFluent<A extends S2iBuildConfigFluent<A>> extends ImageConfigurationFluent<A>{


    public boolean isEnabled();
    public A withEnabled(boolean enabled);
    public Boolean hasEnabled();
    public String getBuilderImage();
    public A withBuilderImage(String builderImage);
    public Boolean hasBuilderImage();
    public A withNewBuilderImage(String arg1);
    public A withNewBuilderImage(StringBuilder arg1);
    public A withNewBuilderImage(StringBuffer arg1);
    public A withBuildEnvVars(io.dekorate.kubernetes.config.Env... buildEnvVars);
    
/**
 * This method has been deprecated, please use method buildBuildEnvVars instead.
 */
@Deprecated public io.dekorate.kubernetes.config.Env[] getBuildEnvVars();
    public io.dekorate.kubernetes.config.Env[] buildBuildEnvVars();
    public io.dekorate.kubernetes.config.Env buildBuildEnvVar(int index);
    public io.dekorate.kubernetes.config.Env buildFirstBuildEnvVar();
    public io.dekorate.kubernetes.config.Env buildLastBuildEnvVar();
    public io.dekorate.kubernetes.config.Env buildMatchingBuildEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate);
    public Boolean hasMatchingBuildEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate);
    public A addToBuildEnvVars(int index,io.dekorate.kubernetes.config.Env item);
    public A setToBuildEnvVars(int index,io.dekorate.kubernetes.config.Env item);
    public A addToBuildEnvVars(io.dekorate.kubernetes.config.Env... items);
    public A addAllToConfigBuildEnvVars(Collection<io.dekorate.kubernetes.config.Env> items);
    public A removeFromBuildEnvVars(io.dekorate.kubernetes.config.Env... items);
    public A removeAllFromConfigBuildEnvVars(Collection<io.dekorate.kubernetes.config.Env> items);
    public A removeMatchingFromConfigBuildEnvVars(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate);
    public Boolean hasBuildEnvVars();
    public A addNewConfigBuildEnvVar(String name,String value,String secret,String configmap,String field);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> addNewConfigBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> addNewBuildEnvVarLike(io.dekorate.kubernetes.config.Env item);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> setNewBuildEnvVarLike(int index,io.dekorate.kubernetes.config.Env item);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editBuildEnvVar(int index);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editFirstBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editLastBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editMatchingBuildEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate);
    public boolean isAutoDeployEnabled();
    public A withAutoDeployEnabled(boolean autoDeployEnabled);
    public Boolean hasAutoDeployEnabled();

    public interface ConfigBuildEnvVarsNested<N> extends io.dekorate.deps.kubernetes.api.builder.Nested<N>,EnvFluent<S2iBuildConfigFluent.ConfigBuildEnvVarsNested<N>>{

        
    public N and();    public N endConfigBuildEnvVar();
}


}

==> s2i-annotations-2.4.1-sources.jar: io/dekorate/s2i/config/S2iBuildConfigFluent.java <==
package io.dekorate.s2i.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.kubernetes.config.ConfigKey;
import java.lang.StringBuilder;
import io.dekorate.kubernetes.config.EnvFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import io.dekorate.kubernetes.config.ImageConfigurationFluent;
import java.util.function.Predicate;
import io.dekorate.project.Project;
import java.lang.StringBuffer;
import io.dekorate.kubernetes.config.EnvBuilder;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface S2iBuildConfigFluent<A extends S2iBuildConfigFluent<A>> extends ImageConfigurationFluent<A> {


    public Boolean getEnabled();
    public A withEnabled(Boolean enabled);
    public Boolean hasEnabled();
    public A withNewEnabled(String arg1);
    public A withNewEnabled(boolean arg1);
    public String getBuilderImage();
    public A withBuilderImage(String builderImage);
    public Boolean hasBuilderImage();
    public A withNewBuilderImage(String arg1);
    public A withNewBuilderImage(StringBuilder arg1);
    public A withNewBuilderImage(StringBuffer arg1);
    public A withBuildEnvVars(io.dekorate.kubernetes.config.Env... buildEnvVars);
    
/**
 * This method has been deprecated, please use method buildBuildEnvVars instead.
 */
@Deprecated public io.dekorate.kubernetes.config.Env[] getBuildEnvVars();
    public io.dekorate.kubernetes.config.Env[] buildBuildEnvVars();
    public io.dekorate.kubernetes.config.Env buildBuildEnvVar(int index);
    public io.dekorate.kubernetes.config.Env buildFirstBuildEnvVar();
    public io.dekorate.kubernetes.config.Env buildLastBuildEnvVar();
    public io.dekorate.kubernetes.config.Env buildMatchingBuildEnvVar(Predicate<EnvBuilder> predicate);
    public Boolean hasMatchingBuildEnvVar(Predicate<EnvBuilder> predicate);
    public A addToBuildEnvVars(int index,io.dekorate.kubernetes.config.Env item);
    public A setToBuildEnvVars(int index,io.dekorate.kubernetes.config.Env item);
    public A addToBuildEnvVars(io.dekorate.kubernetes.config.Env... items);
    public A addAllToConfigBuildEnvVars(Collection<io.dekorate.kubernetes.config.Env> items);
    public A removeFromBuildEnvVars(io.dekorate.kubernetes.config.Env... items);
    public A removeAllFromConfigBuildEnvVars(Collection<io.dekorate.kubernetes.config.Env> items);
    public A removeMatchingFromConfigBuildEnvVars(Predicate<EnvBuilder> predicate);
    public Boolean hasBuildEnvVars();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> addNewConfigBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> addNewBuildEnvVarLike(io.dekorate.kubernetes.config.Env item);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> setNewBuildEnvVarLike(int index,io.dekorate.kubernetes.config.Env item);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editBuildEnvVar(int index);
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editFirstBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editLastBuildEnvVar();
    public S2iBuildConfigFluent.ConfigBuildEnvVarsNested<A> editMatchingBuildEnvVar(Predicate<EnvBuilder> predicate);
    public Boolean getAutoDeployEnabled();
    public A withAutoDeployEnabled(Boolean autoDeployEnabled);
    public Boolean hasAutoDeployEnabled();
    public A withNewAutoDeployEnabled(String arg1);
    public A withNewAutoDeployEnabled(boolean arg1);
    public interface ConfigBuildEnvVarsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EnvFluent<S2iBuildConfigFluent.ConfigBuildEnvVarsNested<N>> {

            public N and();
            public N endConfigBuildEnvVar();    }


}
